@@ -28,7 +28,6 @@ from pgm.utils import classinit, maths
 from pgm.timing import modifier, ticker
 import math, time, gobject
 
-
 # Repeat behavior constants
 FORWARD, REVERSE = 0, 1
 # End behavior constants
@@ -256,9 +255,12 @@ class Controller(object):
 
     # Protected methods
 
-    def update(self):
+    def update(self, update_time=0):
         # Compute elapsed time
-        self._update_time = long(time.time() * 1000)
+        if update_time != 0:
+            self._update_time = update_time
+        else:
+            self._update_time = long(time.time() * 1000)
         diff_begin_time = self._update_time - self._begin_time
 
         # Is the controller duration elapsed ?
